@@ -25,7 +25,7 @@
 extern "C" {
 #endif
 
-#define LIBGNUTLS_VERSION "0.2.3"
+#define LIBGNUTLS_VERSION "0.2.4"
 
 #include <sys/types.h>
 
@@ -49,7 +49,7 @@ typedef enum AlertDescription { GNUTLS_CLOSE_NOTIFY, GNUTLS_UNEXPECTED_MESSAGE=1
 			GNUTLS_NO_RENEGOTIATION=100
 			} AlertDescription;
 
-
+typedef enum GNUTLS_NAME_IND { GNUTLS_DNSNAME=1 } GNUTLS_NAME_IND; 
 typedef enum CertificateStatus { GNUTLS_CERT_TRUSTED=1, GNUTLS_CERT_NOT_TRUSTED, GNUTLS_CERT_EXPIRED, GNUTLS_CERT_INVALID, GNUTLS_CERT_NONE } CertificateStatus;
 typedef enum CertificateRequest { GNUTLS_CERT_REQUEST=1, GNUTLS_CERT_REQUIRE } CertificateRequest;
 typedef enum CloseRequest { GNUTLS_SHUT_RDWR=0, GNUTLS_SHUT_WR=1 } CloseRequest;
@@ -87,6 +87,7 @@ int gnutls_handshake(SOCKET cd, GNUTLS_STATE state);
 int gnutls_check_pending(GNUTLS_STATE state);
 int gnutls_rehandshake(SOCKET cd, GNUTLS_STATE state);
 
+
 AlertDescription gnutls_get_last_alert( GNUTLS_STATE state);
 int gnutls_send_alert(SOCKET, GNUTLS_STATE, AlertLevel, AlertDescription);
 
@@ -136,6 +137,8 @@ int gnutls_set_cache_expiration( GNUTLS_STATE state, int seconds);
 int gnutls_set_db_name( GNUTLS_STATE state, char* filename);	
 int gnutls_clean_db( GNUTLS_STATE state);
 
+void gnutls_set_max_handshake_data_buffer_size( GNUTLS_STATE state, int max);
+
 /* returns libgnutls version */
 const char* gnutls_check_version();
 
@@ -151,8 +154,8 @@ void* gnutls_get_auth_info( GNUTLS_STATE);
  * This will only exist if the client supports the dnsname
  * TLS extension. (draft-ietf-tls-extensions)
  */
-const char* gnutls_ext_get_dnsname( GNUTLS_STATE);
-int gnutls_ext_set_dnsname( GNUTLS_STATE, const char* dnsname);
+const void* gnutls_ext_get_name_ind( GNUTLS_STATE state, GNUTLS_NAME_IND ind);
+int gnutls_ext_set_name_ind( GNUTLS_STATE state, GNUTLS_NAME_IND ind, const void* name);
 
 /* This will set the Common Name field in case of X509PKI
  * authentication. This will be used while verifying the
@@ -172,7 +175,6 @@ typedef struct DSTRUCT* SRP_CLIENT_CREDENTIALS;
 typedef struct DSTRUCT* ANON_SERVER_CREDENTIALS;
 typedef struct DSTRUCT* ANON_CLIENT_CREDENTIALS;
 
-
 void gnutls_free_srp_client_sc( SRP_CLIENT_CREDENTIALS sc);
 int gnutls_allocate_srp_client_sc( SRP_CLIENT_CREDENTIALS *sc);
 int gnutls_set_srp_client_cred( SRP_CLIENT_CREDENTIALS res, char *username, char* password);
@@ -214,6 +216,9 @@ int gnutls_set_x509_trust( X509PKI_CREDENTIALS res, char* CAFILE, char* CRLFILE)
 int gnutls_global_init();
 void gnutls_global_deinit();
 
+int gnutls_dh_replace_params( gnutls_datum prime, gnutls_datum generator, int bits);
+int gnutls_dh_generate_params( gnutls_datum* prime, gnutls_datum* generator, int bits);
+
 typedef ssize_t (*RECV_FUNC)(SOCKET, void*, size_t,int);
 typedef ssize_t (*SEND_FUNC)(SOCKET, const void*, size_t,int);
 typedef void (*LOG_FUNC)( const char*);
@@ -268,6 +273,8 @@ typedef struct {
 #define X509KEY_ENCIPHER_ONLY		2
 #define X509KEY_DECIPHER_ONLY		1
 
+typedef int x509_cert_callback_func(gnutls_DN *, gnutls_DN *, int, gnutls_DN *, int);
+
 
 # ifdef LIBGNUTLS_VERSION /* defined only in gnutls.h */
 
@@ -285,7 +292,7 @@ int gnutls_anon_client_get_dh_bits(  ANON_CLIENT_AUTH_INFO info);
 
 /* X509PKI */
 
-int gnutls_set_x509_cert_callback( X509PKI_CREDENTIALS, int (*x509_cert_callback)(gnutls_DN*, gnutls_DN*, int, gnutls_DN*, int));
+int gnutls_set_x509_cert_callback( X509PKI_CREDENTIALS, x509_cert_callback_func *);
 int gnutls_x509pki_set_cert_request( GNUTLS_STATE, CertificateRequest);
 
 const gnutls_DN* gnutls_x509pki_get_peer_dn(  X509PKI_CLIENT_AUTH_INFO info);
@@ -296,6 +303,10 @@ time_t gnutls_x509pki_get_peer_certificate_activation_time(  X509PKI_CLIENT_AUTH
 time_t gnutls_x509pki_get_peer_certificate_expiration_time(  X509PKI_CLIENT_AUTH_INFO info);
 unsigned char gnutls_x509pki_get_key_usage(  X509PKI_CLIENT_AUTH_INFO info);
 const char* gnutls_x509pki_get_subject_dns_name(  X509PKI_CLIENT_AUTH_INFO info);
+int gnutls_x509pki_get_dh_bits(  X509PKI_CLIENT_AUTH_INFO info);
+
+#define gnutls_x509pki_server_get_dh_bits gnutls_x509pki_get_dh_bits
+#define gnutls_x509pki_client_get_dh_bits gnutls_x509pki_get_dh_bits
 
 #define gnutls_x509pki_server_get_peer_dn gnutls_x509pki_get_peer_dn
 #define gnutls_x509pki_server_get_issuer_dn gnutls_x509pki_get_issuer_dn
@@ -372,6 +383,7 @@ const char* gnutls_x509pki_get_subject_dns_name(  X509PKI_CLIENT_AUTH_INFO info)
 #define GNUTLS_E_X509_KEY_USAGE_VIOLATION -48
 #define GNUTLS_E_PKCS1_WRONG_PAD -48
 #define GNUTLS_E_NO_CERTIFICATE_FOUND -49
+#define GNUTLS_E_INVALID_PARAMETERS -50
 
 #define GNUTLS_E_UNIMPLEMENTED_FEATURE -250
 
