@@ -85,6 +85,7 @@ static gnutls_error_entry error_algorithms[] = {
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_REHANDSHAKE, 0),
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_GOT_APPLICATION_DATA, 0),
 	GNUTLS_ERROR_ENTRY( GNUTLS_E_DB_ERROR, 1),
+	GNUTLS_ERROR_ENTRY( GNUTLS_E_INVALID_PARAMETERS, 1),
 	{0}
 };
 
@@ -162,11 +163,13 @@ void _gnutls_log( const char *fmt, ...) {
  char str[MAX_LOG_SIZE];
  void (*log_func)() = _gnutls_log_func;
  
+ if (_gnutls_log_func==NULL) return;
+
  va_start(args,fmt);
  vsprintf( str,fmt,args);
  va_end(args);   
-  
+
  log_func( str);
- 
+
  return;
 }
