@@ -30,9 +30,9 @@
 #define BUFFERS_DEBUG
 #define HARD_DEBUG
 #define RECORD_DEBUG
-#define HANDSHAKE_DEBUG
+#define HANDSHAKE_DEBUG*/
 #define DEBUG
-*/
+
 
 #define SOCKET int
 #define LIST ...
@@ -41,6 +41,11 @@
 #define MAX24 16777215
 #define MAX16 65535
 
+/* The sequence of handshake messages should not
+ * be larger than this value.
+ */
+#define MAX_HANDSHAKE_DATA_BUFFER_SIZE 128*1024
+
 #define TLS_RANDOM_SIZE 32
 #define TLS_MAX_SESSION_ID_SIZE 32
 #define TLS_MASTER_SIZE 48
@@ -99,7 +104,6 @@ typedef enum HandshakeType { GNUTLS_HELLO_REQUEST, GNUTLS_CLIENT_HELLO, GNUTLS_S
 		     GNUTLS_CERTIFICATE_REQUEST, GNUTLS_SERVER_HELLO_DONE,
 		     GNUTLS_CERTIFICATE_VERIFY, GNUTLS_CLIENT_KEY_EXCHANGE,
 		     GNUTLS_FINISHED=20 } HandshakeType;
-			
 
 typedef struct {
 	ChangeCipherSpecType type;
@@ -194,6 +198,7 @@ typedef struct GNUTLS_KEY_INT* GNUTLS_KEY;
 
 #include <gnutls_hash_int.h>
 #include <gnutls_cipher_int.h>
+#include <gnutls_cert.h>
 
 typedef struct {
 	uint8 CipherSuite[2];
@@ -203,9 +208,16 @@ typedef struct {
  * mechanism. (some extensions may hold parameters in AUTH_INFO
  * structures instead - see SRP).
  */
+typedef enum GNUTLS_NAME_IND { GNUTLS_DNSNAME=1 } GNUTLS_NAME_IND; 
+
 typedef struct {
 	opaque dnsname[MAX_DNSNAME_SIZE];
-	opaque srp_username[MAX_SRP_USERNAME];
+	GNUTLS_NAME_IND type;
+} name_ind;
+
+typedef struct {
+	name_ind	name;
+	opaque 		srp_username[MAX_SRP_USERNAME];
 } TLSExtensions;
 
 /* AUTH_INFO structures MUST NOT contain malloced 
@@ -374,6 +386,8 @@ typedef struct {
 	 * client certificates were found.
 	 */
 	int				(*x509_client_cert_callback)(void*,void*,int, void*, int);
+	gnutls_cert			peer_cert;
+	int				max_handshake_data_buffer_size;
 } GNUTLS_INTERNALS;
 
 struct GNUTLS_STATE_INT {
