@@ -18,9 +18,9 @@
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA
  */
 
-#include <defines.h>
 #include "gnutls_int.h"
 #include "gnutls_algorithms.h"
+#include "gnutls_errors.h"
 
 /* the prototypes for these are in gnutls.h */
 
@@ -36,31 +36,35 @@
   * not use the algorithm's priority except for disabling
   * algorithms that were not specified.
   **/
-void gnutls_set_cipher_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_cipher_priority( GNUTLS_STATE state, LIST) {
 	
 	va_list ap;
-	int i, num=0;
-	BulkCipherAlgorithm* _ap;
-	
+	int i,num=0;
+	va_list _ap;
+
 	va_start( ap, state);
 
 	_ap = ap;
 
-	i=0;
-	do {
+	while( va_arg(ap, BulkCipherAlgorithm) != 0) {
 		num++;
-	} while( _ap[++i] != 0);
+	} 
 
 	if (state->gnutls_internals.BulkCipherAlgorithmPriority.algorithm_priority!=NULL)
 		gnutls_free(state->gnutls_internals.BulkCipherAlgorithmPriority.algorithm_priority);
 	state->gnutls_internals.BulkCipherAlgorithmPriority.algorithm_priority = gnutls_malloc(sizeof(int*)*num);
+	if (state->gnutls_internals.BulkCipherAlgorithmPriority.algorithm_priority == NULL)
+		return GNUTLS_E_MEMORY_ERROR;
+		
 	state->gnutls_internals.BulkCipherAlgorithmPriority.algorithms = num;
 	
 	for (i=0;i<num;i++) {
-		state->gnutls_internals.BulkCipherAlgorithmPriority.algorithm_priority[i] = _ap[i];
+		state->gnutls_internals.BulkCipherAlgorithmPriority.algorithm_priority[i] = va_arg(_ap, BulkCipherAlgorithm);
 	}
 	
 	va_end(ap);
+
+	return 0;
 }
 
 /**
@@ -75,31 +79,32 @@ void gnutls_set_cipher_priority( GNUTLS_STATE state, LIST) {
   * not use the algorithm's priority except for disabling
   * algorithms that were not specified.
  **/
-void gnutls_set_kx_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_kx_priority( GNUTLS_STATE state, LIST) {
 	
 	va_list ap;
-	int i, num=0;
-	KXAlgorithm *_ap;
+	va_list _ap;
+	int i,num=0;
 	
 	va_start( ap, state);
-
 	_ap = ap;
 
-	i=0;
-	do {
+	while( va_arg(ap, KXAlgorithm) != 0) {
 		num++;
-	} while( _ap[++i] != 0);
+	}
 
 	if (state->gnutls_internals.KXAlgorithmPriority.algorithm_priority!=NULL)
 		gnutls_free(state->gnutls_internals.KXAlgorithmPriority.algorithm_priority);
 	state->gnutls_internals.KXAlgorithmPriority.algorithm_priority = gnutls_malloc(sizeof(int*)*num);
+	if (state->gnutls_internals.KXAlgorithmPriority.algorithm_priority==NULL)
+		return GNUTLS_E_MEMORY_ERROR;
 	state->gnutls_internals.KXAlgorithmPriority.algorithms = num;
 
 	for (i=0;i<num;i++) {
-		state->gnutls_internals.KXAlgorithmPriority.algorithm_priority[i] = _ap[i];
+		state->gnutls_internals.KXAlgorithmPriority.algorithm_priority[i] = va_arg( _ap, KXAlgorithm);
 	}
 
 	va_end(ap);
+	return 0;
 }
 
 /**
@@ -114,31 +119,32 @@ void gnutls_set_kx_priority( GNUTLS_STATE state, LIST) {
   * not use the algorithm's priority except for disabling
   * algorithms that were not specified.
   **/
-void gnutls_set_mac_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_mac_priority( GNUTLS_STATE state, LIST) {
 	
 	va_list ap;
 	int i, num=0;
-	MACAlgorithm *_ap;
+	va_list _ap;
 	
 	va_start( ap, state);
 
 	_ap = ap;
-
-	i=0;
-	do {
+	while( va_arg(ap, MACAlgorithm) != 0) {
 		num++;
-	} while( _ap[++i] != 0);
+	}
 	
 	if (state->gnutls_internals.MACAlgorithmPriority.algorithm_priority!=NULL)
 		gnutls_free(state->gnutls_internals.MACAlgorithmPriority.algorithm_priority);	
 	state->gnutls_internals.MACAlgorithmPriority.algorithm_priority = gnutls_malloc(sizeof(int*)*num);
+	if (state->gnutls_internals.MACAlgorithmPriority.algorithm_priority ==NULL)
+		return GNUTLS_E_MEMORY_ERROR;
 	state->gnutls_internals.MACAlgorithmPriority.algorithms = num;
 
 	for (i=0;i<num;i++) {
-		state->gnutls_internals.MACAlgorithmPriority.algorithm_priority[i] = _ap[i];
+		state->gnutls_internals.MACAlgorithmPriority.algorithm_priority[i] = va_arg(_ap, MACAlgorithm);
 	}
 
 	va_end(ap);
+	return 0;
 }
 
 /**
@@ -153,27 +159,76 @@ void gnutls_set_mac_priority( GNUTLS_STATE state, LIST) {
   * not use the algorithm's priority except for disabling
   * algorithms that were not specified.
   **/
-void gnutls_set_compression_priority( GNUTLS_STATE state, LIST) {
+int gnutls_set_compression_priority( GNUTLS_STATE state, LIST) {
 	
 	va_list ap;
-	int i, num=0;
-	CompressionMethod *_ap;
+	int i,num=0;
+	va_list _ap;
 	
 	va_start( ap, state);
-
 	_ap = ap;
 
-	i=0;
-	do {
+	while( va_arg( ap, CompressionMethod) != 0) {
 		num++;
-	} while( _ap[++i] != 0);
+	}
 	
 	if (state->gnutls_internals.CompressionMethodPriority.algorithm_priority!=NULL)
 		gnutls_free(state->gnutls_internals.CompressionMethodPriority.algorithm_priority);	
 	state->gnutls_internals.CompressionMethodPriority.algorithm_priority = gnutls_malloc(sizeof(int*)*num);
+	if (state->gnutls_internals.CompressionMethodPriority.algorithm_priority == NULL)
+		return GNUTLS_E_MEMORY_ERROR;
+
 	state->gnutls_internals.CompressionMethodPriority.algorithms = num;
 	for (i=0;i<num;i++) {
-		state->gnutls_internals.CompressionMethodPriority.algorithm_priority[i] = _ap[i];
+		state->gnutls_internals.CompressionMethodPriority.algorithm_priority[i] = va_arg( _ap, CompressionMethod);
 	}
 	va_end(ap);
+	return 0;
+}
+
+/**
+  * gnutls_set_protocol_priority - Sets the priority on the protocol versions supported by gnutls.
+  * @state: is a &GNUTLS_STATE structure.
+  * @LIST: is a 0 terminated list of GNUTLS_Version elements.
+  *
+  * Sets the priority on the protocol versions supported by gnutls.
+  * Priority is higher for protocols specified before others.
+  * After specifying the protocols you want, you should add 0.
+  * Note that the priority is set on the client. The server does
+  * not use the protocols's priority except for disabling
+  * protocols that were not specified.
+  **/
+int gnutls_set_protocol_priority( GNUTLS_STATE state, LIST) {
+	
+	va_list ap;
+	int i,num=0;
+	va_list _ap;
+	
+	va_start( ap, state);
+	_ap = ap;
+
+	while( va_arg( ap, int) != 0) {
+		num++;
+	}
+	
+	if (state->gnutls_internals.ProtocolPriority.algorithm_priority!=NULL)
+		gnutls_free(state->gnutls_internals.ProtocolPriority.algorithm_priority);
+
+	state->gnutls_internals.ProtocolPriority.algorithm_priority = gnutls_malloc(sizeof(int*)*num);
+
+	if (state->gnutls_internals.ProtocolPriority.algorithm_priority == NULL) {
+		gnutls_assert();
+		return GNUTLS_E_MEMORY_ERROR;
+	}
+	
+	state->gnutls_internals.ProtocolPriority.algorithms = num;
+	for (i=0;i<num;i++) {
+		state->gnutls_internals.ProtocolPriority.algorithm_priority[i] = va_arg( _ap, int);
+	}
+	va_end(ap);
+
+	/* set the current version to the lowest
+	 */
+	_gnutls_set_current_version( state, state->gnutls_internals.ProtocolPriority.algorithm_priority[num-1]);
+	return 0;
 }
