@@ -103,6 +103,8 @@ int gnutls_init(GNUTLS_STATE * state, ConnectionEnd con_end)
 
 	gnutls_set_lowat((*state), DEFAULT_LOWAT); /* the default for tcp */
 
+	gnutls_set_max_handshake_data_buffer_size( (*state), MAX_HANDSHAKE_DATA_BUFFER_SIZE);
+
 	/* everything else not initialized here is initialized
 	 * as NULL or 0. This is why calloc is used.
 	 */
@@ -178,6 +180,7 @@ int gnutls_deinit(GNUTLS_STATE state)
 	GNUTLS_FREE(state->gnutls_internals.CompressionMethodPriority.algorithm_priority);
 
 	GNUTLS_FREE(state->gnutls_internals.db_name);
+	gnutls_free_cert( state->gnutls_internals.peer_cert);
 
 	memset( state, 0, sizeof(struct GNUTLS_STATE_INT));
 	GNUTLS_FREE(state);
