@@ -27,109 +27,10 @@
 #include <gnutls_gcry.h>
 #include "debug.h"
 
-/* These should be added in gcrypt.h */
-MPI _gcry_generate_elg_prime( int mode, unsigned pbits, unsigned qbits,
-	                MPI g, MPI **ret_factors );
 
 /* Here functions for SRP (like g^x mod n) are defined 
  */
 
-/* Taken from gsti -- this is n 
- */
-
-const uint8 diffie_hellman_group1_prime[130] = { 0x04, 0x00,
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xC9, 0x0F, 0xDA,
-	0xA2, 0x21, 0x68, 0xC2, 0x34, 0xC4, 0xC6, 0x62, 0x8B, 0x80, 0xDC, 
-	0x1C, 0xD1, 0x29, 0x02, 0x4E, 0x08, 0x8A, 0x67, 0xCC, 0x74, 0x02, 
-	0x0B, 0xBE, 0xA6, 0x3B, 0x13, 0x9B, 0x22, 0x51, 0x4A, 0x08, 0x79, 
-	0x8E, 0x34, 0x04, 0xDD, 0xEF, 0x95, 0x19, 0xB3, 0xCD, 0x3A, 0x43, 
-	0x1B, 0x30, 0x2B, 0x0A, 0x6D, 0xF2, 0x5F, 0x14, 0x37, 0x4F, 0xE1, 
-	0x35, 0x6D, 0x6D, 0x51, 0xC2, 0x45, 0xE4, 0x85, 0xB5, 0x76, 0x62, 
-	0x5E, 0x7E, 0xC6, 0xF4, 0x4C, 0x42, 0xE9, 0xA6, 0x37, 0xED, 0x6B, 
-	0x0B, 0xFF, 0x5C, 0xB6, 0xF4, 0x06, 0xB7, 0xED, 0xEE, 0x38, 0x6B, 
-	0xFB, 0x5A, 0x89, 0x9F, 0xA5, 0xAE, 0x9F, 0x24, 0x11, 0x7C, 0x4B, 
-	0x1F, 0xE6, 0x49, 0x28, 0x66, 0x51, 0xEC, 0xE6, 0x53, 0x81, 0xFF, 
-	0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF, 0xFF
-};
-
-int _gnutls_srp_gn(opaque ** ret_g, opaque ** ret_n, int bits)
-{
-
-	MPI g, prime;
-	size_t n;
-	int siz, qbits;
-	char *tmp;
-
-	n = sizeof diffie_hellman_group1_prime;
-
-	if (bits == n * 8) {
-		if (gcry_mpi_scan(&prime, GCRYMPI_FMT_USG,
-				  diffie_hellman_group1_prime, &n)) {
-			gnutls_assert();
-			return GNUTLS_E_MPI_SCAN_FAILED;
-		}
-		g = gcry_mpi_set_ui(NULL, SRP_G);
-		if (g==NULL) {
-			gnutls_assert();
-			return GNUTLS_E_MEMORY_ERROR;
-		}
-	} else {
-		g = mpi_new(16); /* this should be ok */
-		if (g==NULL) {
-			gnutls_assert();
-			return GNUTLS_E_MEMORY_ERROR;
-		}
-
-		/* generate a random prime */
-		/* this is an emulation of Michael Wiener's table
-		   * bad emulation.
-		 */
-		qbits = 120 + (((bits / 256) - 1) * 20);
-		if (qbits & 1)	/* better have a even one */
-			qbits++;
-
-		prime = _gcry_generate_elg_prime(0, bits, qbits, g, NULL);
-
-	}
-
-
-	siz = 0;
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &siz, g);
-	if (ret_g != NULL) {
-		tmp = gnutls_malloc(siz);
-		if (tmp==NULL) return GNUTLS_E_MEMORY_ERROR;
-		
-		gcry_mpi_print(GCRYMPI_FMT_USG, tmp, &siz, g);
-
-		if (_gnutls_sbase64_encode(tmp, siz, ret_g) < 0) {
-			gnutls_free(tmp);
-			return GNUTLS_E_UNKNOWN_ERROR;
-		}
-		gnutls_free(tmp);
-	}
-
-	siz = 0;
-	gcry_mpi_print(GCRYMPI_FMT_USG, NULL, &siz, prime);
-	if (ret_n != NULL) {
-		tmp = gnutls_malloc(siz);
-		if (tmp==NULL) return GNUTLS_E_MEMORY_ERROR;
-
-		gcry_mpi_print(GCRYMPI_FMT_USG, tmp, &siz, prime);
-		if (_gnutls_sbase64_encode(tmp, siz, ret_n) < 0) {
-			gnutls_free(tmp);
-			return GNUTLS_E_UNKNOWN_ERROR;
-		}
-
-		gnutls_free(tmp);
-	}
-
-	_gnutls_mpi_release(&g);
-	_gnutls_mpi_release(&prime);
-
-	return 0;
-
-}
-
 
 int _gnutls_srp_gx(opaque * text, int textsize, opaque ** result, MPI g,
 		   MPI prime)
